@@ -1,7 +1,6 @@
 ;;; semantic/bovine/el.el --- Semantic details for Emacs Lisp
 
-;; Copyright (C) 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2007, 2008,
-;;   2009, 2010, 2011, 2012  Free Software Foundation, Inc.
+;; Copyright (C) 1999-2005, 2007-2012  Free Software Foundation, Inc.
 
 ;; Author: Eric M. Ludlam <zappo@gnu.org>
 
@@ -464,7 +463,7 @@ Return a bovination list to use."
 	  ;; Try an Emacs 22 fcn.  This throws errors.
 	  (find-library-name (semantic-tag-name tag))
 	(error
-	 (message "semantic: connot find source file %s"
+	 (message "semantic: cannot find source file %s"
 		  (semantic-tag-name tag))))
     ;; No handy function available.  (Older Emacsen)
     (let* ((lib (locate-library (semantic-tag-name tag)))
@@ -498,15 +497,15 @@ used to perform the override."
 Unfortunately, this requires that the tag in question has been loaded
 into Emacs Lisp's memory."
   (let ((obsoletethis (intern-soft (semantic-tag-name tag)))
-	(obsoletor nil))
+	(obsoleter nil))
     ;; This asks if our tag is available in the Emacs name space for querying.
     (when obsoletethis
       (mapatoms (lambda (a)
 		  (let ((oi (get a 'byte-obsolete-info)))
 		    (if (and oi (eq (car oi) obsoletethis))
-			(setq obsoletor a)))))
-      (if obsoletor
-	  (format "\n@obsolete{%s,%s}" obsoletor (semantic-tag-name tag))
+			(setq obsoleter a)))))
+      (if obsoleter
+	  (format "\n@obsolete{%s,%s}" obsoleter (semantic-tag-name tag))
 	""))))
 
 (define-mode-local-override semantic-documentation-for-tag
@@ -516,7 +515,7 @@ Optional argument NOSNARF is ignored."
   (let ((d (semantic-tag-docstring tag)))
     (when (not d)
       (cond ((semantic-tag-with-position-p tag)
-	     ;; Doc isn't in the tag itself.  Lets pull it out of the
+	     ;; Doc isn't in the tag itself.  Let's pull it out of the
 	     ;; sources.
 	     (let ((semantic-elisp-store-documentation-in-tag t))
 	       (setq tag (with-current-buffer (semantic-tag-buffer tag)
@@ -535,9 +534,9 @@ Optional argument NOSNARF is ignored."
 		     (t
 		      (setq d (documentation-property
 			       sym 'variable-documentation)))))
-	     ;; Label it as system doc.. perhaps just for debugging
+	     ;; Label it as system doc. perhaps just for debugging
 	     ;; purposes.
-	     (if d (setq d (concat "Sytem Doc: \n" d)))
+	     (if d (setq d (concat "System Doc: \n" d)))
 	     ))
       )
 
@@ -824,7 +823,7 @@ In Emacs Lisp this is easily defined by parenthesis bounding."
   (&optional point)
   "Return a list of tag classes allowed at POINT.
 Emacs Lisp knows much more about the class of the tag needed to perform
-completion than some languages.  We distincly know if we are to be a
+completion than some languages.  We distinctly know if we are to be a
 function name, variable name, or any type of symbol.  We could identify
 fields and such to, but that is for some other day."
   (save-excursion
@@ -864,7 +863,7 @@ fields and such to, but that is for some other day."
 In Emacs Lisp, a prototype for something may start (autoload ...).
 This is certainly not expected if this is used to display a summary.
 Make up something else.  When we go to write something that needs
-a real Emacs Lisp protype, we can fix it then."
+a real Emacs Lisp prototype, we can fix it then."
   (let ((class (semantic-tag-class tag))
 	(name (semantic-format-tag-name tag parent color))
 	)
@@ -963,5 +962,4 @@ ELisp variables can be pretty long, so track this one too.")
 
 (provide 'semantic/bovine/el)
 
-;; arch-tag: d634cbab-9610-4510-9fce-048ae1eb7aa6
 ;;; semantic/bovine/el.el ends here
