@@ -1,7 +1,6 @@
 ;;; disass.el --- disassembler for compiled Emacs Lisp code
 
-;; Copyright (C) 1986, 1991, 2002, 2003, 2004,
-;;   2005, 2006, 2007, 2008, 2009, 2010 Free Software Foundation, Inc.
+;; Copyright (C) 1986, 1991, 2002-2012 Free Software Foundation, Inc.
 
 ;; Author: Doug Cutting <doug@csli.stanford.edu>
 ;;	Jamie Zawinski <jwz@lucid.com>
@@ -79,13 +78,14 @@ redefine OBJECT if it is a symbol."
 	    obj (symbol-function obj)))
     (if (subrp obj)
 	(error "Can't disassemble #<subr %s>" name))
-    (if (and (listp obj) (eq (car obj) 'autoload))
-	(progn
-	  (load (nth 1 obj))
-	  (setq obj (symbol-function name))))
+    (when (and (listp obj) (eq (car obj) 'autoload))
+      (load (nth 1 obj))
+      (setq obj (symbol-function name)))
     (if (eq (car-safe obj) 'macro)	;handle macros
 	(setq macro t
 	      obj (cdr obj)))
+    (when (and (listp obj) (eq (car obj) 'closure))
+      (error "Don't know how to compile an interpreted closure"))
     (if (and (listp obj) (eq (car obj) 'byte-code))
 	(setq obj (list 'lambda nil obj)))
     (if (and (listp obj) (not (eq (car obj) 'lambda)))
@@ -216,7 +216,9 @@ OBJ should be a call to BYTE-CODE generated by the byte compiler."
 	  (cond ((memq op byte-goto-ops)
 		 (insert (int-to-string (nth 1 arg))))
 		((memq op '(byte-call byte-unbind
-			    byte-listN byte-concatN byte-insertN))
+			    byte-listN byte-concatN byte-insertN
+			    byte-stack-ref byte-stack-set byte-stack-set2
+			    byte-discardN byte-discardN-preserve-tos))
 		 (insert (int-to-string arg)))
 		((memq op '(byte-varref byte-varset byte-varbind))
 		 (prin1 (car arg) (current-buffer)))
@@ -249,10 +251,10 @@ OBJ should be a call to BYTE-CODE generated by the byte compiler."
 		       ((eq (car-safe (car-safe arg)) 'byte-code)
 			(insert "(<byte code>...)\n")
 			(mapc ;recurse on list of byte-code objects
-			 '(lambda (obj)
-			    (disassemble-1
-			     obj
-			     (+ indent disassemble-recursive-indent)))
+			 (lambda (obj)
+                           (disassemble-1
+                            obj
+                            (+ indent disassemble-recursive-indent)))
 			 arg))
 		       (t
 			;; really just a constant
@@ -264,5 +266,4 @@ OBJ should be a call to BYTE-CODE generated by the byte compiler."
 
 (provide 'disass)
 
-;; arch-tag: 89482fe4-a087-4761-8dc6-d771054e763a
 ;;; disass.el ends here
