@@ -1,7 +1,6 @@
 ;;; em-basic.el --- basic shell builtin commands
 
-;; Copyright (C) 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007,
-;;   2008, 2009  Free Software Foundation, Inc.
+;; Copyright (C) 1999-2012  Free Software Foundation, Inc.
 
 ;; Author: John Wiegley <johnw@gnu.org>
 
@@ -77,7 +76,7 @@ same thing."
   :group 'eshell-module)
 
 (defcustom eshell-plain-echo-behavior nil
-  "*If non-nil, `echo' tries to behave like an ordinary shell echo.
+  "If non-nil, `echo' tries to behave like an ordinary shell echo.
 This comes at some detriment to Lisp functionality.  However, the Lisp
 equivalent of `echo' can always be achieved by using `identity'."
   :type 'boolean
@@ -125,7 +124,7 @@ or `eshell-printn' for display."
    (eshell-echo args output-newline)))
 
 (defun eshell/printnl (&rest args)
-  "Print out each of the argument, separated by newlines."
+  "Print out each of the arguments, separated by newlines."
   (let ((elems (eshell-flatten-list args)))
     (while elems
       (eshell-printn (eshell-echo (list (car elems))))
@@ -184,5 +183,4 @@ or `eshell-printn' for display."
 ;; generated-autoload-file: "esh-groups.el"
 ;; End:
 
-;; arch-tag: 385a31b1-cb95-46f0-9829-9d352ee77db8
 ;;; em-basic.el ends here
