@@ -1,7 +1,6 @@
 ;;; mh-junk.el --- MH-E interface to anti-spam measures
 
-;; Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012
-;;   Free Software Foundation, Inc.
+;; Copyright (C) 2003-2012  Free Software Foundation, Inc.
 
 ;; Author: Satyaki Das <satyaki@theforce.stanford.edu>,
 ;;         Bill Wohler <wohler@newt.com>
@@ -313,9 +312,9 @@ information can be used so that you can replace multiple
     (delete-other-windows)
     (pop-to-buffer (get-buffer-create "*MH-E Spammer Frequencies*"))
     (erase-buffer)
-    (maphash '(lambda (key value) ""
-                (if (> value 2)
-                    (insert (format "%s %s\n" key value))))
+    (maphash (lambda (key value) ""
+               (if (> value 2)
+                   (insert (format "%s %s\n" key value))))
              domains)
     (sort-numeric-fields 2 (point-min) (point-max))
     (reverse-region (point-min) (point-max))
@@ -467,5 +466,4 @@ See `mh-spamprobe-blacklist' for more information."
 ;; sentence-end-double-space: nil
 ;; End:
 
-;; arch-tag: 603335f1-77ff-4306-8828-5d3dad51abe1
 ;;; mh-junk.el ends here
