@@ -1,6 +1,6 @@
 ;;; rng-maint.el --- commands for RELAX NG maintainers
 
-;; Copyright (C) 2003, 2007, 2008, 2009, 2010, 2011, 2012 Free Software Foundation, Inc.
+;; Copyright (C) 2003, 2007-2012 Free Software Foundation, Inc.
 
 ;; Author: James Clark
 ;; Keywords: XML, RelaxNG
@@ -224,19 +224,13 @@
 
 ;;; Timing
 
-(defun rng-time-to-float (time)
-  (+ (* (nth 0 time) 65536.0)
-     (nth 1 time)
-     (/ (nth 2 time) 1000000.0)))
-
 (defun rng-time-function (function &rest args)
   (let* ((start (current-time))
 	 (val (apply function args))
 	 (end (current-time)))
     (message "%s ran in %g seconds"
 	     function
-	     (- (rng-time-to-float end)
-		(rng-time-to-float start)))
+	     (float-time (time-subtract end start)))
     val))
 
 (defun rng-time-tokenize-buffer ()
@@ -275,5 +269,4 @@
   (while (rng-do-some-validation
 	  (lambda () t))))
 
-;; arch-tag: 4b8c6143-daac-4888-9c61-9bea6f935f17
 ;;; rng-maint.el ends here
