@@ -1,10 +1,10 @@
 ;;; vc-mcvs.el --- VC backend for the Meta-CVS version-control system
 
-;; Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012
-;;   Free Software Foundation, Inc.
+;; Copyright (C) 2003-2012  Free Software Foundation, Inc.
 
 ;; Author:      FSF (see vc.el for full credits)
 ;; Maintainer:  None
+;; Obsolete-since: 23.1
 
 ;; This file is part of GNU Emacs.
 
@@ -31,9 +31,6 @@
 ;;
 ;; ********** READ THIS! **********
 
-;; This file has been obsolete and unsupported since Emacs 23.1.
-
-
 ;; The home page of the Meta-CVS version control system is at
 ;;
 ;;      http://users.footprints.net/~kaz/mcvs.html
@@ -102,10 +99,9 @@ If nil, use the value of `vc-diff-switches'.  If t, use no switches."
   :version "22.1"
   :group 'vc)
 
-(defcustom vc-mcvs-header (or (cdr (assoc 'MCVS vc-header-alist))
-			      vc-cvs-header)
+(defcustom vc-mcvs-header vc-cvs-header
   "Header keywords to be inserted by `vc-insert-headers'."
-  :version "22.1"
+  :version "24.1"     ; no longer consult the obsolete vc-header-alist
   :type '(repeat string)
   :group 'vc)
 
@@ -586,5 +582,4 @@ and that it passes `vc-mcvs-global-switches' to it before FLAGS."
 ;;
 ;; ********** READ THIS! **********
 
-;; arch-tag: a39c7c1c-5247-429d-88df-dd7187d2e704
 ;;; vc-mcvs.el ends here
