@@ -1,7 +1,8 @@
 ;;; pcmpl-rpm.el --- functions for dealing with rpm completions
 
-;; Copyright (C) 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007,
-;;   2008, 2009, 2010, 2011, 2012  Free Software Foundation, Inc.
+;; Copyright (C) 1999-2012 Free Software Foundation, Inc.
+
+;; Package: pcomplete
 
 ;; This file is part of GNU Emacs.
 
@@ -28,6 +29,13 @@
 
 ;; Functions:
 
+;; FIXME rpm -qa can be slow, so:
+;; Adding --nodigest --nosignature is MUCH faster.
+;; (Probably need to test --help for those options though.)
+;; Consider caching the result (cf woman).
+;; Consider printing an explanatory message before running -qa.
+;;
+;; Seems pointless for this to be a defsubst.
 (defsubst pcmpl-rpm-packages ()
   (split-string (pcomplete-process-result "rpm" "-q" "-a")))
 
@@ -91,6 +99,7 @@
 	       '("--changelog"
 		 "--dbpath"
 		 "--dump"
+		 "--file"
 		 "--ftpport"            ;nyi for the next four
 		 "--ftpproxy"
 		 "--httpport"
@@ -111,6 +120,8 @@
 		(pcomplete-here*))
 	       ((pcomplete-test "--rcfile")
 		(pcomplete-here* (pcomplete-entries)))
+	       ((pcomplete-test "--file")
+		(pcomplete-here* (pcomplete-entries)))
 	       ((pcomplete-test "--root")
 		(pcomplete-here* (pcomplete-dirs)))
 	       ((pcomplete-test "--scripts")
@@ -128,7 +139,9 @@
 	      (pcomplete-opt "af.p(pcmpl-rpm-files)ilsdcvR")
 	    (if (pcomplete-test "-[^-]*p" 'first 1)
 		(pcomplete-here (pcmpl-rpm-files))
-	      (pcomplete-here (pcmpl-rpm-packages))))))
+              (if (pcomplete-test "-[^-]*f" 'first 1)
+                  (pcomplete-here* (pcomplete-entries))
+                (pcomplete-here (pcmpl-rpm-packages)))))))
        ((pcomplete-test "--pipe")
 	(pcomplete-here* (funcall pcomplete-command-completion-function)))
        ((pcomplete-test "--rmsource")
@@ -312,13 +325,12 @@
 	  (if (pcomplete-match "^-" 0)
 	      (pcomplete-opt "v")
 	    (pcomplete-here
-	     (if (eq mode 'test)
-		 (pcomplete-dirs-or-entries "\\.tar\\'")
-	       (pcomplete-dirs-or-entries "\\.spec\\'"))))))
+	     (pcomplete-dirs-or-entries (if (eq mode 'test)
+                                            "\\.tar\\'"
+                                          "\\.spec\\'"))))))
        (t
 	(error "You must select a mode: -q, -i, -U, --verify, etc"))))))
 
 (provide 'pcmpl-rpm)
 
-;; arch-tag: 4e64b490-fecf-430e-b2b9-70a8ad64b8c1
 ;;; pcmpl-rpm.el ends here
