@@ -1,7 +1,6 @@
 ;;; url-dav.el --- WebDAV support
 
-;; Copyright (C) 2001, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012
-;;   Free Software Foundation, Inc.
+;; Copyright (C) 2001, 2004-2012  Free Software Foundation, Inc.
 
 ;; Author: Bill Perry <wmperry@gnu.org>
 ;; Maintainer: Bill Perry <wmperry@gnu.org>
@@ -118,7 +117,7 @@
     ;; We need to populate 'time' with
     ;; (SEC MIN HOUR DAY MON YEAR DOW DST TZ)
 
-    ;; Nobody else handles iso8601 correctly, lets do it ourselves.
+    ;; Nobody else handles iso8601 correctly, let's do it ourselves.
     (when (string-match date-re date-string re-start)
       (setq year (string-to-number (match-string 1 date-string))
 	    month (string-to-number (match-string 2 date-string))
@@ -418,7 +417,7 @@ XML document."
 Automatically creates an XML request body if TAG is non-nil.
 BODY is the XML document fragment to be enclosed by <TAG></TAG>.
 
-DEPTH is how deep the request should propogate.  Default is 0, meaning
+DEPTH is how deep the request should propagate.  Default is 0, meaning
 it should apply only to URL.  A negative number means to use
 `Infinity' for the depth.  Not all WebDAV servers support this depth
 though.
@@ -431,7 +430,7 @@ added to this list, so most requests can just pass in nil."
   ;; Take care of the default value for depth...
   (setq depth (or depth 0))
 
-  ;; Now lets translate it into something webdav can understand.
+  ;; Now let's translate it into something webdav can understand.
   (if (< depth 0)
       (setq depth "Infinity")
     (setq depth (int-to-string depth)))
@@ -763,7 +762,7 @@ files in the collection as well."
 	    (setq status (plist-get (cdr result) 'DAV:status))
 	    (if (not (url-dav-http-success-p status))
 		(signal 'file-error (list "Removing old name"
-					  "Errror removing"
+					  "Error removing"
 					  (car result) status))))
 	  props))
   nil)
@@ -910,7 +909,7 @@ Returns nil if URL contains no name starting with FILE."
       ;; Only one file and FILE matches it exactly...
       t)
      (t
-      ;; Need to figure out the longest string that they have in commmon
+      ;; Need to figure out the longest string that they have in common
       (setq matches (sort matches (lambda (a b) (> (length a) (length b)))))
       (let ((n (length file))
 	    (searching t)
@@ -963,5 +962,4 @@ Returns nil if URL contains no name starting with FILE."
 
 (provide 'url-dav)
 
-;; arch-tag: 2b14b7b3-888a-49b8-a490-17276a40e78e
 ;;; url-dav.el ends here
