@@ -1,6 +1,5 @@
 /* systime.h - System-dependent definitions for time manipulations.
-   Copyright (C) 1993, 1994, 2002, 2003, 2004,
-                 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software Foundation, Inc.
+   Copyright (C) 1993-1994, 2002-2012 Free Software Foundation, Inc.
 
 This file is part of GNU Emacs.
 
@@ -31,15 +30,12 @@ along with GNU Emacs.  If not, see <http://www.gnu.org/licenses/>.  */
 #endif
 #endif
 
-#ifdef HAVE_TZNAME
-#ifndef tzname		/* For SGI.  */
-extern char *tzname[];	/* RS6000 and others want it this way.  */
-#endif
-#endif
-
-/* SVr4 doesn't actually declare this in its #include files.  */
-#ifdef USG5_4
-extern time_t timezone;
+#ifdef emacs
+# ifdef HAVE_X_WINDOWS
+#  include <X11/X.h>
+# else
+typedef unsigned long Time;
+# endif
 #endif
 
 /* On some configurations (hpux8.0, X11R4), sys/time.h and X11/Xos.h
@@ -136,17 +132,18 @@ extern time_t timezone;
 #define EMACS_SET_SECS_USECS(time, secs, usecs) 		\
   (EMACS_SET_SECS (time, secs), EMACS_SET_USECS (time, usecs))
 
-extern int set_file_times __P ((const char *, EMACS_TIME, EMACS_TIME));
+extern int set_file_times (const char *, EMACS_TIME, EMACS_TIME);
 
 /* defined in keyboard.c */
-extern void set_waiting_for_input __P ((EMACS_TIME *));
+extern void set_waiting_for_input (EMACS_TIME *);
 
 /* When lisp.h is not included Lisp_Object is not defined (this can
    happen when this files is used outside the src directory).
    Use GCPRO1 to determine if lisp.h was included.  */
 #ifdef GCPRO1
-/* defined in dired.c */
-extern Lisp_Object make_time __P ((time_t));
+/* defined in editfns.c*/
+extern Lisp_Object make_time (time_t);
+extern int lisp_time_argument (Lisp_Object, time_t *, int *);
 #endif
 
 /* Compare times T1 and T2.  Value is 0 if T1 and T2 are the same.
@@ -170,6 +167,3 @@ extern Lisp_Object make_time __P ((time_t));
 #define EMACS_TIME_LE(T1, T2) (EMACS_TIME_CMP (T1, T2) <= 0)
 
 #endif /* EMACS_SYSTIME_H */
-
-/* arch-tag: dcb79915-cf99-4bce-9778-aade71d07651
-   (do not change this comment) */
