@@ -1,6 +1,5 @@
 /* The emacs frame widget private header file.
-   Copyright (C) 1993, 2001, 2002, 2003, 2004, 2005,
-                 2006, 2007, 2008, 2009, 2010, 2011, 2012  Free Software Foundation, Inc.
+   Copyright (C) 1993, 2001-2012  Free Software Foundation, Inc.
 
 This file is part of GNU Emacs.
 
@@ -71,11 +70,4 @@ typedef struct _EmacsFrameClassRec {	/* full class record declaration */
     EmacsFrameClassPart	emacs_frame_class;
 } EmacsFrameClassRec;
 
-extern EmacsFrameClassRec emacsFrameClassRec;	 /* class pointer */
-
-
-
 #endif /* _EmacsFrameP_h */
-
-/* arch-tag: 2b579b4c-f697-4f86-b27a-35b7cb1a4a1c
-   (do not change this comment) */
